@@ -11,8 +11,7 @@ sample_data = False
 
 EOF
 
-
 cat setup.cfg
 sed -i.bak "s|/usr/local|${PREFIX}|" setupext.py
 
-${PYTHON} -m pip install . --no-deps -vv
\ No newline at end of file
+$PYTHON -m pip install . --no-deps -vv
